@@ -16,8 +16,9 @@ import time
 
 def df_retainCols(dfdata, collist): #deletes columns in df which are not there in list of columns
     # collist (a list) should contain the list of columns to be retained
-    dfdata.drop(columns=[col for col in dfdata if col not in collist], inplace=True)
-    return dfdata
+    dfdata1 = dfdata
+    dfdata1.drop(columns=[col for col in dfdata1 if col not in collist], inplace=True)
+    return dfdata1
 
 def df_delCcols(dfdata, collist): #deletes columns in df which are there in list of columns
     # collist (a list) should contain the list of columns to be deleted
